@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,12 +39,13 @@
 #endif
 
 #include "cw.h"
-#include "libcw.h"
-#include "libcw_debug.h"
 
-#include "i18n.h"
-#include "cw_cmdline.h"
-#include "cw_copyright.h"
+#include <libcw.h>
+#include <libcw_debug.h>
+
+#include <cwutils/i18n.h>
+#include <cwutils/cw_cmdline.h>
+#include <cwutils/cw_copyright.h>
 
 
 /*---------------------------------------------------------------------*/
@@ -65,7 +66,7 @@ static void write_to_cw_sender (const char *format, ...)
 static void signal_handler(int signal_number);
 static void cw_atexit(void);
 
-static cw_config_t *config = NULL; /* program-specific configuration */
+static cw_config_t *config; /* program-specific configuration */
 static bool generator = false;     /* have we created a generator? */
 static bool g_is_running = false;
 
@@ -166,7 +167,8 @@ write_to_cw_sender (const char *format, ...)
 static void
 parse_stream_query (FILE *stream)
 {
-  int c, value;
+  int c;
+  int value;
 
   c = toupper (getc_unlocked (stream));
   switch (c)
@@ -222,7 +224,8 @@ parse_stream_query (FILE *stream)
 static void
 parse_stream_cwquery (FILE *stream)
 {
-  int c, value;
+  int c;
+  int value;
   const char *format;
 
   c = toupper (getc_unlocked (stream));
@@ -431,7 +434,8 @@ parse_stream_command (FILE *stream)
 static void
 send_cw_character (int c, int is_partial)
 {
-  int character, status;
+  int character;
+  int status;
 
   /* Convert all whitespace into a single space. */
   character = isspace (c) ? ' ' : c;
