@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,13 +39,13 @@
 # include <strings.h>
 #endif
 
-#include "libcw.h"
-#include "i18n.h"
-#include "cw_cmdline.h"
-#include "cw_copyright.h"
-#include "dictionary.h"
-#include "memory.h"
+#include <libcw.h>
 
+#include <cwutils/i18n.h>
+#include <cwutils/cw_cmdline.h>
+#include <cwutils/cw_copyright.h>
+#include <cwutils/dictionary.h>
+#include <cwutils/memory.h>
 
 
 
@@ -70,7 +70,7 @@ static bool is_sending_active = false;
 #define CWCP_PARAM_WIDTH (15 + 1)
 
 
-static cw_config_t *config = NULL; /* program-specific configuration */
+static cw_config_t *config; /* program-specific configuration */
 static bool generator = false;     /* have we created a generator? */
 
 
@@ -228,7 +228,7 @@ void queue_display_add_character(void)
 {
 	/* Append the last queued character to the text display. */
 	if (queue_get_length() > 0) {
-		waddch(text_subwindow, toupper(queue_data[queue_tail]));
+		waddch(text_subwindow, toupper((int) queue_data[queue_tail]));
 		wrefresh(text_subwindow);
 	}
 
@@ -244,7 +244,9 @@ void queue_display_add_character(void)
 */
 void queue_display_delete_character(void)
 {
-	int y, x, max_x;
+	int y;
+	int x;
+	int max_x;
 	__attribute__((unused)) int max_y;
 
 	/* Get the text display dimensions and current coordinates. */
@@ -278,7 +280,9 @@ void queue_display_delete_character(void)
 */
 void queue_display_highlight_character(bool is_highlight)
 {
-	int y, x, max_x;
+	int y;
+	int x;
+	int max_x;
 	__attribute__((unused)) int max_y;
 
 	/* Get the text display dimensions and current coordinates. */
@@ -296,7 +300,8 @@ void queue_display_highlight_character(bool is_highlight)
 	   unhighlight, and then restore the cursor position so that
 	   it remains unchanged. */
 	if (y >= 0) {
-		int saved_y, saved_x;
+		int saved_y;
+		int saved_x;
 
 		getyx(text_subwindow, saved_y, saved_x);
 		wmove(text_subwindow, y, x);
@@ -386,7 +391,7 @@ void queue_enqueue_string(const char *word)
 	bool is_queue_notify = false;
 	for (int i = 0; word[i] != '\0'; i++) {
 
-		char c = toupper(word[i]);
+		char c = toupper((int) word[i]);
 		if (cw_character_is_valid(c)) {
 			/* Calculate the new character queue tail.  If
 			   the new value will not hit the current
@@ -918,9 +923,9 @@ bool mode_is_sending_active(void)
  * character limit imposed by ISO C89 on string literal lengths.
  */
 static const char *const INTRODUCTION = N_(
-  "UNIX/Linux Morse Tutor v3.6.0\n"
+  "UNIX/Linux Morse Tutor v3.6.1\n"
   "Copyright (C) 1997-2006 Simon Baldwin\n"
-  "Copyright (C) 2011-2021 Kamil Ignacak\n"
+  "Copyright (C) 2011-2023 Kamil Ignacak\n"
   "---------------------------------------------------------\n"
   "Cwcp is an interactive Morse code tutor program, designed\n"
   "both for learning Morse code for the first time, and for\n"
@@ -1093,7 +1098,8 @@ void ui_initialize(void)
 {
 	static bool is_initialized = false;
 
-	int max_y, max_x;
+	int max_y;
+	int max_x;
 
 	/* Create the over-arching screen window. */
 	screen = ui_init_screen();
@@ -1559,7 +1565,7 @@ void ui_poll_user_input(int fd, int usecs)
 		struct timeval timeout;
 
 		/* Set up a the file descriptor set and timeout information. */
-		FD_ZERO(&read_set);
+		FD_ZERO(&read_set); // NOLINT(readability-isolate-declaration) // NOLINT because I can't fix problem in sys/select.h
 		FD_SET(fd, &read_set);
 		timeout.tv_sec = usecs / 1000000;
 		timeout.tv_usec = usecs % 1000000;
