@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,11 +35,10 @@
 # include <strings.h>
 #endif
 
-#include "i18n.h"
-#include "cw_cmdline.h"
-#include "cw_copyright.h"
-#include "memory.h"
-
+#include <cwutils/i18n.h>
+#include <cwutils/cw_cmdline.h>
+#include <cwutils/cw_copyright.h>
+#include <cwutils/memory.h>
 
 
 
@@ -115,6 +114,7 @@ void cwgen_generate_characters(struct cwgen_config *config)
 		struct timeval t;
 		gettimeofday(&t, NULL);
 
+		/* TODO acerion 2023.10.01 use API from src/cwutils/lib/random.h. */
 		srandom(t.tv_usec);
 		is_initialized = true;
 	}
