@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -90,28 +90,9 @@ const char *cw_program_basename(const char *argv0)
 
 
 
-
-/**
-   \brief Combine command line options and environment options
-
-   Build a new argc and argv by combining command line and environment
-   options.
-
-   The new values are held in the heap, and the malloc'ed addresses
-   are not retained, so do not call this function repeatedly,
-   otherwise it will leak memory.
-
-   Combined values are returned through \p new_argc and \p new_argv.
-
-   \param env_variable - name of environment variable to read from
-   \param argc - argc of program's main()
-   \param argv - argv[] of program's main()
-   \param new_argc - combined argc
-   \param new_argv[] - combined argv
-*/
-int combine_arguments(const char *env_variable,
-		      int argc, char *const argv[],
-		      /* out */ int *new_argc, /* out */ char **new_argv[])
+int combine_arguments(const char * env_variable,
+                      int argc, char * const argv[],
+                      int * new_argc, char ** new_argv[])
 {
 	/* Begin with argv[0], which stays in place. */
 	char **local_argv = malloc(sizeof (*local_argv));
@@ -123,35 +104,56 @@ int combine_arguments(const char *env_variable,
 	local_argv[local_argc++] = argv[0];
 
 	/* If options are given in an environment variable, add these next. */
-	char *env_options = getenv(env_variable);
+	char * env_options = getenv(env_variable);
+	char * options = NULL;
 	if (env_options) {
-		char *options = strdup(env_options);
+		options = strdup(env_options);
 		if (NULL == options) {
 			fprintf(stderr, "strdup() failure\n"); /* TODO: better error handling. */
+			free(local_argv);
+			local_argv = NULL;
 			return CW_FAILURE;
 		}
 
+		int env_options_count = 0;
 		for (char *option = strtok(options, " \t");
 		     option;
 		     option = strtok(NULL, " \t")) {
 
-			local_argv = realloc(local_argv, sizeof (*local_argv) * (local_argc + 1));
-			if (NULL == local_argv) {
+			char ** realloced = realloc(local_argv, sizeof (*local_argv) * (local_argc + 1));
+			if (NULL == realloced) {
 				fprintf(stderr, "realloc() error\n"); /* TODO: better error handling. */
+				free(local_argv);
+				local_argv = NULL;
+				free(options);
+				options = NULL;
 				return CW_FAILURE;
 			}
+			local_argv = realloced;
 			local_argv[local_argc++] = option;
+			env_options_count++;
+		}
+
+		if (NULL != options && 0 == env_options_count) {
+			/* String duplicated/allocated with strdup(env_options) is not
+			   put in local_argv[], so it's not needed anymore. */
+			free(options);
+			options = NULL;
 		}
 	}
 
 	/* Append the options given on the command line itself. */
 	for (int arg = 1; arg < argc; arg++) {
-		local_argv = realloc(local_argv,
-				     sizeof (*local_argv) * (local_argc + 1));
-		if (NULL == local_argv) {
+		char ** realloced = realloc(local_argv, sizeof (*local_argv) * (local_argc + 1));
+		if (NULL == realloced) {
 			fprintf(stderr, "realloc() error\n"); /* TODO: better error handling. */
+			free(local_argv);
+			local_argv = NULL;
+			free(options);
+			options = NULL;
 			return CW_FAILURE;
 		}
+		local_argv = realloced;
 		local_argv[local_argc++] = argv[arg];
 	}
 
@@ -165,7 +167,6 @@ int combine_arguments(const char *env_variable,
 
 
 
-
 /*---------------------------------------------------------------------*/
 /*  Option handling helpers                                            */
 /*---------------------------------------------------------------------*/
@@ -262,6 +263,8 @@ int get_option(int argc, char *const argv[],
 			option_string = realloc(option_string, strlen(option_string) + 3);
 			if (NULL == option_string) {
 				fprintf(stderr, "realloc() error\n"); /* TODO: better error handling. */
+				free(options);
+				options = NULL;
 				return false;
 			}
 			strncat(option_string, element, needs_arg ? 2 : 1);
@@ -275,11 +278,15 @@ int get_option(int argc, char *const argv[],
 						  sizeof (*long_names) * (long_count + 1));
 			if (NULL == long_names) {
 				fprintf(stderr, "realloc() error\n"); /* TODO: better error handling. */
+				free(options);
+				options = NULL;
 				return false;
 			}
 			long_names[long_count] = strdup(element + (needs_arg ? 3 : 2));
 			if (NULL == long_names[long_count]) {
 				fprintf(stderr, "strdup() failure\n"); /* TODO: better error handling. */
+				free(options);
+				options = NULL;
 				return false;
 			}
 
@@ -288,12 +295,14 @@ int get_option(int argc, char *const argv[],
 					       sizeof (*long_options) * (long_count + 2));
 			if (NULL == long_options) {
 				fprintf(stderr, "realloc() error\n"); /* TODO: better error handling. */
+				free(options);
+				options = NULL;
 				return false;
 			}
 			long_options[long_count].name = long_names[long_count];
 			long_options[long_count].has_arg = needs_arg;
 			long_options[long_count].flag = NULL;
-			long_options[long_count].val = element[0];
+			long_options[long_count].val = (int) element[0];
 			long_count++;
 
 			/* Set the end sentry to all zeroes. */
@@ -443,8 +452,7 @@ void cw_print_help(cw_config_t *config)
 	if (config->has_feature_cw_specific
 	    || config->has_feature_practice_time
 	    || config->has_feature_infile
-	    || config->has_feature_outfile
-	    || config->has_feature_cw_specific) {
+	    || config->has_feature_outfile) {
 
 		fprintf(stderr, "%s", _("Other options:\n"));
 
@@ -673,7 +681,7 @@ int cw_process_option(int opt, const char *optarg, cw_config_t *config)
 		if (optarg && strlen(optarg)) {
 			const size_t len_max = sizeof (config->gen_conf.sound_device) - 1;
 			if (strlen(optarg) >= len_max) {
-				fprintf(stderr, "%s: device name can't be longer than %zd characters\n", config->program_name, len_max);
+				fprintf(stderr, "%s: device name can't be longer than %zu characters\n", config->program_name, len_max);
 				return CW_FAILURE;
 			}
 			snprintf(config->gen_conf.sound_device, sizeof (config->gen_conf.sound_device), "%s", optarg);
@@ -817,6 +825,25 @@ int cw_process_option(int opt, const char *optarg, cw_config_t *config)
 
 
 	case 'S':
+		/*
+		  None of libcw's "cw_is_X_possible()" functions is called here.
+		  Checking if given sound system is available on current machine is
+		  present in libcw test program.
+
+		  The reason for this is calls to "cw_is_X_possible()" must be done
+		  even if "-S" option is not provided.
+
+		  By default, when "-S" is not specified, all sound systems should be
+		  tested by libcw tester. In that case the calls to
+		  "cw_is_X_possible()" still have to be executed, but they logically
+		  can't be executed here.
+
+		  In such situation the calls will be done in libcw tester, and since
+		  the calls are done there when "-S" is not used, I decide to make
+		  the calls in the tester when "-S" IS used. The code in the tester
+		  is structured in a way that avoids any duplication of
+		  "cw_is_X_possible()".
+		*/
 		optarg_len = strlen(optarg);
 		if (optarg_len > strlen(LIBCW_TEST_ALL_SOUND_SYSTEMS)) {
 			fprintf(stderr, "Too many values for 'sound system' option: '%s'\n", optarg);
@@ -825,7 +852,7 @@ int cw_process_option(int opt, const char *optarg, cw_config_t *config)
 
 		dest_idx = 0;
 		for (size_t i = 0; i < optarg_len; i++) {
-			const int val = optarg[i];
+			const int val = (int) optarg[i];
 			if (NULL == strchr(LIBCW_TEST_ALL_SOUND_SYSTEMS, val)) {
 				fprintf(stderr, "Unsupported sound system '%c'\n", val);
 				goto help_and_error;
@@ -836,56 +863,22 @@ int cw_process_option(int opt, const char *optarg, cw_config_t *config)
 			   Otherwise we may mislead the user. */
 			switch (val) {
 			case 'n':
-				if (cw_is_null_possible(NULL)) {
-					config->tested_sound_systems[dest_idx] = CW_AUDIO_NULL;
-					dest_idx++;
-				} else {
-					fprintf(stderr, "Requested null sound system is not available on this machine\n");
-					goto help_and_error;
-				}
+				config->tested_sound_systems[dest_idx++] = CW_AUDIO_NULL;
 				break;
 			case 'c':
-				if (cw_is_console_possible(NULL)) {
-					config->tested_sound_systems[dest_idx] = CW_AUDIO_CONSOLE;
-					dest_idx++;
-				} else {
-					fprintf(stderr, "Requested console sound system is not available on this machine\n");
-					goto help_and_error;
-
-				}
+				config->tested_sound_systems[dest_idx++] = CW_AUDIO_CONSOLE;
 				break;
 			case 'o':
-				if (cw_is_oss_possible(NULL)) {
-					config->tested_sound_systems[dest_idx] = CW_AUDIO_OSS;
-					dest_idx++;
-				} else {
-					fprintf(stderr, "Requested OSS sound system is not available on this machine\n");
-					goto help_and_error;
-
-				}
+				config->tested_sound_systems[dest_idx++] = CW_AUDIO_OSS;
 				break;
 			case 'a':
-				if (cw_is_alsa_possible(NULL)) {
-					config->tested_sound_systems[dest_idx] = CW_AUDIO_ALSA;
-					dest_idx++;
-				} else {
-					fprintf(stderr, "Requested ALSA sound system is not available on this machine\n");
-					goto help_and_error;
-
-				}
+				config->tested_sound_systems[dest_idx++] = CW_AUDIO_ALSA;
 				break;
 			case 'p':
-				if (cw_is_pa_possible(NULL)) {
-					config->tested_sound_systems[dest_idx] = CW_AUDIO_PA;
-					dest_idx++;
-				} else {
-					fprintf(stderr, "Requested PulseAudio sound system is not available on this machine\n");
-					goto help_and_error;
-
-				}
+				config->tested_sound_systems[dest_idx++] = CW_AUDIO_PA;
 				break;
 			default:
-				fprintf(stderr, "Unsupported sound system '%c'\n", val);
+				fprintf(stderr, "[ERROR] Unsupported sound system '%c'\n", val);
 				goto help_and_error;
 			}
 		}
@@ -901,7 +894,7 @@ int cw_process_option(int opt, const char *optarg, cw_config_t *config)
 
 		dest_idx = 0;
 		for (size_t i = 0; i < optarg_len; i++) {
-			const int val = optarg[i];
+			const int val = (int) optarg[i];
 			if (NULL == strchr(LIBCW_TEST_ALL_TOPICS, val)) {
 				fprintf(stderr, "Unsupported test area '%c'\n", val);
 				goto help_and_error;
@@ -951,7 +944,7 @@ int cw_process_option(int opt, const char *optarg, cw_config_t *config)
 		break;
 
 	case 'D':
-		config->test_random_seed = atol(optarg);
+		config->test_random_seed = (uint32_t) atol(optarg);
 		break;
 
 	default: /* '?' */
