@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -334,8 +334,10 @@ bool cw_dictionary_parse_is_section(const char *line, char **name_ptr)
 static const char **
 dictionary_build_wordlist (char *wordlist_data)
 {
-  const char **wordlist, *word;
-  int size, allocation;
+  const char **wordlist;
+  const char *word;
+  int size;
+  int allocation;
 
   /* Split contents into a wordlist, and store each word retrieved. */
   size = allocation = 0;
@@ -555,7 +557,8 @@ cw_dictionary_t *cw_dictionaries_create_from_stream(FILE *stream, const char *fi
 */
 cw_dictionary_t *cw_dictionaries_create_default(void)
 {
-	cw_dictionary_t *head = NULL, *tail = NULL;
+	cw_dictionary_t *head = NULL;
+	cw_dictionary_t *tail = NULL;
 
 	head = dictionary_new_const (NULL, _("Letter Groups"), CW_ALPHABETIC);
 	tail = dictionary_new_const (head, _("Number Groups"), CW_NUMERIC);
@@ -818,6 +821,7 @@ const char *cw_dictionary_get_random_word(const cw_dictionary_t *dict)
 
 	/* On the first call, seed the random number generator. */
 	if (!is_initialized) {
+		/* TODO acerion 2023.10.01 use API from src/cwutils/lib/random.h. */
 		srand(time(NULL));
 		is_initialized = true;
 	}
