@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-  Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+  Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -93,7 +93,7 @@ CW_STATIC_FUNC volatile cw_key_t cw_key = {
 
 
 	.sk = {
-		.key_value = CW_KEY_STATE_OPEN
+		.key_value = CW_KEY_VALUE_OPEN
 	},
 
 
@@ -574,7 +574,7 @@ int cw_send_dash(void)
 */
 int cw_send_character_space(void)
 {
-	return cw_gen_enqueue_2u_ics_internal(cw_generator);
+	return cw_gen_enqueue_ics_internal(cw_generator);
 }
 
 
@@ -687,7 +687,7 @@ int cw_send_character(char c)
 /**
    \brief Look up and send a given ASCII character as Morse code
 
-   "partial" means that the "end of character" delay is not appended
+   "partial" means that the inter-character-space is not appended
    to the Morse code sent by the function, to support the formation of
    combination characters.
 
@@ -1110,6 +1110,15 @@ int cw_queue_tone(int usecs, int frequency)
 	CW_TONE_INIT(&tone, frequency, usecs, CW_SLOPE_MODE_STANDARD_SLOPES);
 	int rv = cw_tq_enqueue_internal(cw_generator->tq, &tone);
 
+	if (frequency > 0) {
+		/* Enqueueing a mark must reset counter of spaces. */
+		cw_generator->space_units_count = 0;
+	} else {
+		/* This function doesn't allow us to recognize whether an ims, ics or
+		   iws space has been enqueued, so we can't tell what value to assign
+		   to space_units_count. */
+	}
+
 	return rv;
 }
 
@@ -1631,8 +1640,8 @@ int cw_receive_character(const struct timeval *timestamp,
 			 /* out */ bool *is_end_of_word,
 			 /* out */ bool *is_error)
 {
-	int rv = cw_rec_poll_character(&cw_receiver, timestamp, c, is_end_of_word, is_error);
-	return rv;
+	cw_ret_t cwret = cw_rec_poll_character(&cw_receiver, timestamp, c, is_end_of_word, is_error);
+	return (int) cwret;
 }
 
 
@@ -1655,7 +1664,8 @@ int cw_receive_character(const struct timeval *timestamp,
 */
 void cw_clear_receive_buffer(void)
 {
-	/* In 3.5.1 this was implemented by cw_rec_clear_buffer_internal() like this: */
+	/* In 3.5.1 this was implemented by cw_rec_clear_buffer_internal() (now
+	   cw_rec_reset_state()) like this: */
 
 	memset(cw_receiver.representation, 0, sizeof (cw_receiver.representation));
 	cw_receiver.representation_ind = 0;
