@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-  Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+  Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -35,6 +35,7 @@
 
 #include "libcw_alsa.h"
 #include "libcw_debug.h"
+#include "libcw_debug_internal.h"
 #include "libcw_rec.h"
 
 
@@ -488,13 +489,8 @@ static cw_ret_t cw_alsa_open_and_configure_sound_device_internal(cw_gen_t * gen,
 		gen->buffer_n_samples = period_size;
 	}
 
-#if CW_DEV_RAW_SINK
-	gen->dev_raw_sink = open("/tmp/cw_file.alsa.raw",
-				 O_WRONLY | O_CREAT | O_TRUNC | O_NONBLOCK,
-				 S_IRUSR | S_IWUSR);
-	if (gen->dev_raw_sink == -1) {
-		fprintf(stderr, MSG_PREFIX "open: failed to open dev raw sink file: '%s'\n", strerror(errno));
-	}
+#ifdef ENABLE_DEV_PCM_SAMPLES_FILE
+	cw_dev_debug_raw_sink_open_internal(gen);
 #endif
 
 	gen->sound_device_is_open = true;
@@ -527,11 +523,8 @@ static void cw_alsa_close_sound_device_internal(cw_gen_t * gen)
 		dlclose(cw_alsa.lib_handle);
 	}
 
-#if CW_DEV_RAW_SINK
-	if (gen->dev_raw_sink != -1) {
-		close(gen->dev_raw_sink);
-		gen->dev_raw_sink = -1;
-	}
+#ifdef ENABLE_DEV_PCM_SAMPLES_FILE
+	cw_dev_debug_raw_sink_close_internal(gen);
 #endif
 	return;
 }
@@ -969,10 +962,10 @@ static cw_ret_t cw_alsa_set_hw_params_buffer_size_internal(cw_gen_t * gen, snd_p
 	   parameter to be zero in final configuration space. Better set it
 	   explicitly. */
 	int dir = 0;
-	cw_alsa.snd_pcm_hw_params_set_periods(gen->alsa_data.pcm_handle, hw_params, n_periods, dir);
+	snd_rv = cw_alsa.snd_pcm_hw_params_set_periods(gen->alsa_data.pcm_handle, hw_params, n_periods, dir);
 	if (0 != snd_rv) {
 		cw_debug_msg (&cw_debug_object, CW_DEBUG_SOUND_SYSTEM, CW_DEBUG_ERROR,
-			      MSG_PREFIX "set hw params: can't set periods: %s / %d", cw_alsa.snd_strerror(snd_rv), n_periods);
+		              MSG_PREFIX "set hw params: can't set %d periods: [%s]", n_periods, cw_alsa.snd_strerror(snd_rv));
 		return CW_FAILURE;
 	}
 
@@ -1342,14 +1335,13 @@ static void cw_alsa_get_intended_period_size_internal(const cw_gen_t * gen, snd_
 		/* TODO: maybe we could calculate the period size for
 		   *current* speed and re-configure ALSA hw buffer
 		   every time the speed changes? */
-		cw_gen_durations_t durations = { 0 };
-		cw_gen_calculate_durations_internal(&durations, CW_SPEED_MAX, CW_WEIGHTING_MIN);
+		const int shortest_dot_duration = cw_gen_get_shortest_dot_duration_internal();
 		cw_debug_msg (&cw_debug_object, CW_DEBUG_SOUND_SYSTEM, CW_DEBUG_DEBUG,
-			      MSG_PREFIX "shortest dot = %d [us]", durations.dot_duration);
+			      MSG_PREFIX "shortest dot = %d [us]", shortest_dot_duration);
 
 		/* Now calculate count of ALSA frames that will be
 		   needed to play that shortest dot. */
-		const uint64_t n_alsa_frames_smallest = gen->sample_rate * durations.dot_duration / 1000000;
+		const uint64_t n_alsa_frames_smallest = gen->sample_rate * shortest_dot_duration / 1000000;
 		cw_debug_msg (&cw_debug_object, CW_DEBUG_SOUND_SYSTEM, CW_DEBUG_DEBUG,
 			      MSG_PREFIX "n_samples for shortest dot = %"PRIu64" [samples]", n_alsa_frames_smallest);
 
