@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,9 +35,13 @@
 
 
 #include <errno.h>
+#include <fcntl.h>
+#include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 #include <sys/time.h>
 #include <unistd.h>
 
@@ -46,6 +50,7 @@
 
 #include "libcw.h"
 #include "libcw_debug.h"
+#include "libcw_debug_internal.h"
 #include "libcw_gen.h"
 #include "libcw_utils.h"
 
@@ -298,7 +303,7 @@ bool cw_debug_has_flag(const cw_debug_t * debug_object, uint32_t flag)
 
 
 
-#ifdef LIBCW_WITH_DEV
+#ifdef ENABLE_DEV_LIBCW_DEBUGGING
 
 
 
@@ -371,62 +376,16 @@ void cw_dev_debug_print_generator_setup_internal(const cw_gen_t * gen)
 	fprintf(stderr, "frequency:            %d Hz\n",  gen->frequency);
 	fprintf(stderr, "sound buffer size:    %d\n",     gen->buffer_n_samples);
 
-	fprintf(stderr, "debug sink file:      %s\n", gen->dev_raw_sink != -1 ? "yes" : "no");
-
-	return;
-}
-
-
-
-
-/**
-   @brief Write generator's samples to debug file
-
-   This function does any actual writing only for generators
-   configured to use OSS, Alsa and PulseAudio sound sinks. Using the
-   function on generators configured with other sound sinks doesn't
-   produce any output and the function always returns CW_SUCCESS.
-
-   @internal
-   @reviewed 2020-08-01
-   @endinternal
-
-   @param[in] gen generator
-
-   @return CW_SUCCESS on write success
-   @return CW_FAILURE otherwise
-*/
-int cw_dev_debug_raw_sink_write_internal(cw_gen_t * gen)
-{
-	if (gen->sound_system != CW_AUDIO_OSS
-	    && gen->sound_system != CW_AUDIO_ALSA
-	    && gen->sound_system != CW_AUDIO_PA) {
-
-		return CW_SUCCESS;
-	}
-
+#ifdef ENABLE_DEV_PCM_SAMPLES_FILE
+	fprintf(stderr, "debug sink file:      %s\n",     gen->dev_raw_sink != -1 ? "opened" : "not opened");
 	if (gen->dev_raw_sink != -1) {
-#if CW_DEV_RAW_SINK_MARKERS
-		/* FIXME: this will cause memory access error at
-		   the end, when generator is destroyed in the
-		   other thread */
-		gen->buffer[0] = 0x7fff;
-		gen->buffer[1] = 0x7fff;
-		gen->buffer[samples - 2] = 0x8000;
-		gen->buffer[samples - 1] = 0x8000;
+		fprintf(stderr, "debug sink file path: '%s'\n", gen->dev_raw_sink_path);
+	}
+#else
+	fprintf(stderr, "debug sink file:      disabled\n");
 #endif
 
-		const size_t n_bytes = sizeof (gen->buffer[0]) * gen->buffer_n_samples;
-
-		int rv = write(gen->dev_raw_sink, gen->buffer, n_bytes);
-		if (rv == -1) {
-			cw_debug_msg (&cw_debug_object_dev, CW_DEBUG_STDLIB, CW_DEBUG_ERROR,
-				      MSG_PREFIX "write error: %s (gen->dev_raw_sink = %ld, gen->buffer = %ld, n_bytes = %zu)", strerror(errno), (long) gen->dev_raw_sink, (long) gen->buffer, n_bytes);
-			return CW_FAILURE;
-		}
-	}
-
-	return CW_SUCCESS;
+	return;
 }
 
 
@@ -476,4 +435,90 @@ void cw_debug_event_internal(cw_debug_t * debug_object, uint32_t flag, uint32_t
 
 
 
-#endif /* #ifdef LIBCW_WITH_DEV */
+#endif /* #ifdef ENABLE_DEV_LIBCW_DEBUGGING */
+
+
+
+
+#ifdef ENABLE_DEV_PCM_SAMPLES_FILE
+
+
+
+
+/* Put markers at the beginning and end of buffers (frames) sent to raw sink - or not. */
+#define CW_DEV_RAW_SINK_MARKERS   0
+
+
+
+
+void cw_dev_debug_raw_sink_open_internal(cw_gen_t * gen)
+{
+	/* TODO: this may not be true if int16_t integer is represented by e.g.
+	   32-bit integer on given platform. */
+	const size_t sample_size = sizeof (cw_sample_t) * CHAR_BIT;
+
+	snprintf(gen->dev_raw_sink_path, sizeof (gen->dev_raw_sink_path),
+	         "/tmp/cw_file_%s_%uHz_mono_signed_%zubit_pcm.raw",
+	         cw_get_audio_system_label(gen->sound_system),
+	         gen->sample_rate,
+	         sample_size);
+	gen->dev_raw_sink = open(gen->dev_raw_sink_path,
+	                         O_WRONLY | O_CREAT | O_TRUNC | O_NONBLOCK,
+	                         S_IRUSR | S_IWUSR);
+	if (gen->dev_raw_sink == -1) {
+		fprintf(stderr, MSG_PREFIX "open: failed to open dev raw sink file with path '%s': '%s'\n", gen->dev_raw_sink_path, strerror(errno));
+	}
+}
+
+
+
+
+void cw_dev_debug_raw_sink_close_internal(cw_gen_t * gen)
+{
+	if (gen->dev_raw_sink != -1) {
+		close(gen->dev_raw_sink);
+		gen->dev_raw_sink = -1;
+	}
+}
+
+
+
+
+int cw_dev_debug_raw_sink_write_internal(cw_gen_t * gen)
+{
+	if (gen->sound_system != CW_AUDIO_OSS
+	    && gen->sound_system != CW_AUDIO_ALSA
+	    && gen->sound_system != CW_AUDIO_PA) {
+
+		return CW_SUCCESS;
+	}
+
+	if (gen->dev_raw_sink != -1) {
+#if CW_DEV_RAW_SINK_MARKERS
+		/* FIXME: this will cause memory access error at
+		   the end, when generator is destroyed in the
+		   other thread */
+		gen->buffer[0] = 0x7fff;
+		gen->buffer[1] = 0x7fff;
+		gen->buffer[samples - 2] = 0x8000;
+		gen->buffer[samples - 1] = 0x8000;
+#endif
+
+		const size_t n_bytes = sizeof (gen->buffer[0]) * gen->buffer_n_samples;
+
+		int rv = write(gen->dev_raw_sink, gen->buffer, n_bytes);
+		if (rv == -1) {
+			cw_debug_msg (&cw_debug_object_dev, CW_DEBUG_STDLIB, CW_DEBUG_ERROR,
+				      MSG_PREFIX "write error: %s (gen->dev_raw_sink = %ld, gen->buffer = %ld, n_bytes = %zu)", strerror(errno), (long) gen->dev_raw_sink, (long) gen->buffer, n_bytes);
+			return CW_FAILURE;
+		}
+	}
+
+	return CW_SUCCESS;
+}
+
+
+
+
+#endif /* #ifdef ENABLE_DEV_PCM_SAMPLES_FILE */
+
