@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -217,11 +217,10 @@ enum {
   during development of libcw, and should not be used by client code.
 */
 
-#ifdef LIBCW_WITH_DEV
+#ifdef ENABLE_DEV_LIBCW_DEBUGGING
 /* Including private header in public header is accepted here only because it
    is inside of "build with development tests" flag. */
 #include "libcw_gen.h"
-int  cw_dev_debug_raw_sink_write_internal(cw_gen_t * gen) __attribute__ ((deprecated));
 void cw_dev_debug_print_generator_setup_internal(const cw_gen_t * gen) __attribute__ ((deprecated));
 #endif
 
