@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-  Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+  Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -86,6 +86,7 @@ extern cw_debug_t cw_debug_object_dev;
 
 
 
+#include "libcw_debug_internal.h"
 #include "libcw_gen.h"
 
 
@@ -321,8 +322,8 @@ cw_ret_t cw_oss_open_and_configure_sound_device_internal(cw_gen_t * gen, const c
 	/* Mark sound sink as now open for business. */
 	gen->sound_device_is_open = true;
 
-#if CW_DEV_RAW_SINK
-	gen->dev_raw_sink = open("/tmp/cw_file.oss.raw", O_WRONLY | O_TRUNC | O_NONBLOCK);
+#ifdef ENABLE_DEV_PCM_SAMPLES_FILE
+	cw_dev_debug_raw_sink_open_internal(gen);
 #endif
 
 	return CW_SUCCESS;
@@ -565,11 +566,8 @@ void cw_oss_close_sound_device_internal(cw_gen_t * gen)
 	gen->oss_data.sound_sink_fd = -1;
 	gen->sound_device_is_open = false;
 
-#if CW_DEV_RAW_SINK
-	if (gen->dev_raw_sink != -1) {
-		close(gen->dev_raw_sink);
-		gen->dev_raw_sink = -1;
-	}
+#ifdef ENABLE_DEV_PCM_SAMPLES_FILE
+	cw_dev_debug_raw_sink_close_internal(gen);
 #endif
 	return;
 }
