@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-  Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+  Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -30,12 +30,14 @@
 
 
 #include <stdbool.h>
+#include <stdlib.h>
 
 
 
 
 #include "config.h"
 #include "libcw_debug.h"
+#include "libcw_debug_internal.h"
 #include "libcw_pa.h"
 
 
@@ -191,6 +193,12 @@ bool cw_is_pa_possible(const char * device_name)
 		if (g_cw_pa_lib_handle.lib_handle) { /* FIXME: this closing of global handle won't work well for multi-generator library. */
 			dlclose(g_cw_pa_lib_handle.lib_handle);
 		}
+		/* Without this env an attempt to connect to PulseAudio
+		   server may end with "Connection refused". */
+		if (NULL == getenv("XDG_RUNTIME_DIR")) {
+			cw_debug_msg (&cw_debug_object, CW_DEBUG_SOUND_SYSTEM, CW_DEBUG_WARNING,
+				      MSG_PREFIX "is possible: XDG_RUNTIME_DIR is empty");
+		}
 		return false;
 	} else {
 		/* TODO: verify this comment: We do dlclose(g_cw_pa_lib_handle.lib_handle) in cw_pa_close_sound_device_internal(). */
@@ -409,8 +417,8 @@ static cw_ret_t cw_pa_open_and_configure_sound_device_internal(cw_gen_t * gen, c
 			      MSG_PREFIX "open device: pa_simple_get_latency() failed: %s", g_cw_pa_lib_handle.pa_strerror(error));
 	}
 
-#if CW_DEV_RAW_SINK
-	gen->dev_raw_sink = open("/tmp/cw_file.pa.raw", O_WRONLY | O_TRUNC | O_NONBLOCK);
+#ifdef ENABLE_DEV_PCM_SAMPLES_FILE
+	cw_dev_debug_raw_sink_open_internal(gen);
 #endif
 	assert (gen && gen->pa_data.simple);
 
@@ -451,11 +459,8 @@ static void cw_pa_close_sound_device_internal(cw_gen_t * gen)
 
 	gen->sound_device_is_open = false;
 
-#if CW_DEV_RAW_SINK
-	if (gen->dev_raw_sink != -1) {
-		close(gen->dev_raw_sink);
-		gen->dev_raw_sink = -1;
-	}
+#ifdef ENABLE_DEV_PCM_SAMPLES_FILE
+	cw_dev_debug_raw_sink_close_internal(gen);
 #endif
 	return;
 }
