@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-  Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+  Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -182,7 +182,7 @@ cw_rec_t * cw_rec_new(void)
 
 
 /**
-   @brief Delete a generator
+   @brief Delete a receiver
 
    Deallocate all memory and free all resources associated with given
    receiver that was allocated with cw_rec_new().
@@ -2056,11 +2056,15 @@ void cw_rec_sync_parameters_internal(cw_rec_t * rec)
 	} else {
 		/* Fixed speed receiving mode. */
 
-		int tolerance = (rec->dot_duration_ideal * rec->tolerance) / 100; /* [%] */
-		rec->dot_duration_min = rec->dot_duration_ideal - tolerance;
-		rec->dot_duration_max = rec->dot_duration_ideal + tolerance;
-		rec->dash_duration_min = rec->dash_duration_ideal - tolerance;
-		rec->dash_duration_max = rec->dash_duration_ideal + tolerance;
+		/* Dividing by 100[%] because tolerance is in percents. */
+		const int dot_margin = (rec->dot_duration_ideal * rec->tolerance) / 100; /* [microseconds] */
+
+		rec->dot_duration_min = rec->dot_duration_ideal - dot_margin;
+		rec->dot_duration_max = rec->dot_duration_ideal + dot_margin;
+		/* TODO (acerion) 2023.07.27: shouldn't calculations of dash duration
+		   range be using dash_margin? */
+		rec->dash_duration_min = rec->dash_duration_ideal - dot_margin;
+		rec->dash_duration_max = rec->dash_duration_ideal + dot_margin;
 
 		/* Make the inter-mark-space the same as the dot
 		   duration range. */
