@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-  Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+  Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -62,7 +62,7 @@
 
 
 
-#include "cw_copyright.h"
+#include <cwutils/cw_copyright.h>
 #include "libcw.h"
 #include "libcw2.h"
 #include "libcw_debug.h"
@@ -274,6 +274,7 @@ void cw_usleep_internal(int usecs)
 	do {
 		struct timespec req = { .tv_sec = remaining.tv_sec, .tv_nsec = remaining.tv_nsec };
 		//fprintf(stderr, " -- sleeping for %ld s, %ld ns\n", req.tv_sec, req.tv_nsec);
+		/* TODO acerion 2023.11.11: use clock_nanosleep() with MONOTONIC clock ID. */
 		rv = nanosleep(&req, &remaining);
 		if (rv) {
 			//fprintf(stderr, " -- remains %ld s, %ld ns\n", remaining.tv_sec, remaining.tv_nsec);
@@ -408,8 +409,10 @@ int cw_timestamp_compare_internal(const struct timeval * earlier, const struct t
 {
 	/* Compare the timestamps, taking care on overflows.
 
-	   At 4 WPM, the dash length is 3*(1200000/4)=900,000 usecs, and
-	   the word gap is 2,100,000 usecs.  With the maximum Farnsworth
+	   At 4 WPM, the dash duration is 3*(1200000/4)=900,000 usecs, and
+	   the inter-word-space is 2,100,000 usecs.
+
+	   With the maximum Farnsworth
 	   additional delay, the word gap extends to 20,100,000 usecs.
 	   This fits into an int with a lot of room to spare, in fact, an
 	   int can represent 2,147,483,647 usecs, or around 33 minutes.
