@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -771,7 +771,7 @@ static int test_phonetic_lookups_internal_sub(cw_test_executor_t * cte, char * p
 			   the first letter of phonetic should
 			   be the same as the looked up
 			   letter. */
-			reverse_failure = (phonetic_buffer[0] != toupper((char) i));
+			reverse_failure = (phonetic_buffer[0] != toupper(i));
 			if (!cte->expect_op_int_errors_only(cte, false, "==", reverse_failure, "phonetic lookup: reverse lookup for phonetic \"%s\" ('%c' / #%d)", phonetic_buffer, (char) i, i)) {
 				reverse_failure = true;
 				break;
