@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,12 +34,14 @@
 
 
 
-
+#include "common.h"
+#include "libcw_debug.h"
 #include "libcw_gen.h"
 #include "libcw_gen_tests.h"
-#include "libcw_debug.h"
 #include "libcw_utils.h"
 #include "test_framework.h"
+#include <cw_easy_rec.h>
+#include <cwutils/lib/random.h>
 
 
 
@@ -51,58 +53,8 @@ extern const char * test_invalid_strings[];
 
 
 
-static cwt_retv gen_setup(cw_test_executor_t * cte, cw_gen_t ** gen);
-static void gen_destroy(cw_gen_t ** gen);
 static cwt_retv test_cw_gen_new_start_stop_delete_sub(cw_test_executor_t * cte, const char * function_name, bool do_new, bool do_start, bool do_stop, bool do_delete);
-static cwt_retv test_cw_gen_forever_sub(cw_test_executor_t * cte, int seconds);
-
-
-
-
-/**
-   @brief Prepare new generator, possibly with parameter values passed through command line
-
-   Test helper function.
-
-   @reviewed on 2020-05-07
-
-   @return cwt_retv_ok on success
-   @return cwt_retv_err on failure
-*/
-static cwt_retv gen_setup(cw_test_executor_t * cte, cw_gen_t ** gen)
-{
-	*gen = cw_gen_new(&cte->current_gen_conf);
-	if (!*gen) {
-		cte->log_error(cte, "Can't create generator, stopping the test\n");
-		return cwt_retv_err;
-	}
-
-	cw_gen_reset_parameters_internal(*gen);
-	cw_gen_sync_parameters_internal(*gen);
-	cw_gen_set_speed(*gen, cte->config->send_speed);
-	cw_gen_set_frequency(*gen, cte->config->frequency);
-
-	return cwt_retv_ok;
-}
-
-
-
-
-/**
-   @brief Delete @param gen, set the pointer to NULL
-
-   Test helper function.
-
-   @reviewed on 2020-05-07
-*/
-void gen_destroy(cw_gen_t ** gen)
-{
-	if (NULL != gen) {
-		if (NULL != *gen) {
-			cw_gen_delete(gen);
-		}
-	}
-}
+static int test_cw_gen_forever_sub(cw_test_executor_t * cte, int seconds, bool * pass);
 
 
 
@@ -567,21 +519,30 @@ cwt_retv test_cw_gen_tone_slope_shape_enums(cw_test_executor_t * cte)
    experiencing 100% CPU usage on one of cores with ALSA sound system when HW
    configuration of the ALSA sound system was incorrect.
 
-   @reviewed on 2020-10-15
+   @reviewedon 2023-11-04
 */
-cwt_retv test_cw_gen_forever_internal(cw_test_executor_t * cte)
+cwt_retv test_cw_gen_forever_internal(cw_test_executor_t * kite)
 {
-	const int loops = cte->get_loops_count(cte);
-	const int seconds = 7;
+	kite->print_test_header(kite, "%s", __func__);
 
-	cte->print_test_header(cte, "%s (%d loops, %d seconds)", __func__, loops, seconds);
+	bool pass = true;
 
+	const int loops = kite->get_loops_count(kite);
 	for (int i = 0; i < loops; i++) {
-		const cwt_retv rv = test_cw_gen_forever_sub(cte, seconds);
-		cte->expect_op_int(cte, cwt_retv_ok, "==", rv, "'forever' test");
+		int seconds = 0;
+		if (0 != cw_random_get_int(1, 8, &seconds)) {
+			kite_log(kite, LOG_ERR, "Failed to get random integer for seconds\n");
+			return cwt_retv_err;
+		}
+
+		kite->log_info(kite, "Test %d/%d, %d seconds\n", i + 1, loops, seconds); /* For better information on test progress. */
+		if (0 != test_cw_gen_forever_sub(kite, seconds, &pass)) {
+			kite_log(kite, LOG_ERR, "Failed to test single forever element\n");
+			return cwt_retv_err;
+		}
 	}
 
-	cte->print_test_footer(cte, __func__);
+	kite_on_test_completion(kite, __func__, pass ? test_result_pass : test_result_fail);
 
 	return cwt_retv_ok;
 }
@@ -590,14 +551,28 @@ cwt_retv test_cw_gen_forever_internal(cw_test_executor_t * cte)
 
 
 /**
-   @reviewed on 2020-05-10
+   @brief Enqueue a single "forever" element of given duration
+
+   Function enqueues a single "forever" element, waits for given duration and
+   then terminates the element.
+
+   The "forever" element consists of rising slope, "plateau", and falling slope.
+
+   @reviewedon 2023-11-04
+
+   @param[in/out] cte Test executor
+   @param[in] seconds Duration of enqueued "forever" element
+   @param[out] pass Whether a test passed or failed
+
+   @return 0 if test was performed without interruptions
+   @return -1 otherwise
 */
-static cwt_retv test_cw_gen_forever_sub(cw_test_executor_t * cte, __attribute__((unused)) int seconds)
+static int test_cw_gen_forever_sub(cw_test_executor_t * cte, __attribute__((unused)) int seconds, bool * pass)
 {
 	cw_gen_t * gen = cw_gen_new(&cte->current_gen_conf);
 	if (NULL == gen) {
 		cte->log_error(cte, "failed to create generator\n");
-		return cwt_retv_err;
+		return -1;
 	}
 
 	cw_gen_start(gen);
@@ -610,13 +585,14 @@ static cwt_retv test_cw_gen_forever_sub(cw_test_executor_t * cte, __attribute__(
 	cw_tone_t tone;
 	CW_TONE_INIT(&tone, freq, slope_duration, CW_SLOPE_MODE_RISING_SLOPE);
 	const cw_ret_t cwret1 = cw_tq_enqueue_internal(gen->tq, &tone);
-	cte->expect_op_int_errors_only(cte, CW_SUCCESS, "==", cwret1, "enqueue first tone"); /* Use "errors only" here because this is not a core part of test. */
+	/* Use "errors only" here because this is not a core part of test. */
+	(*pass) = cte->expect_op_int_errors_only(cte, CW_SUCCESS, "==", cwret1, "enqueue first tone") && (*pass);
 
 	CW_TONE_INIT(&tone, freq, gen->quantum_duration, CW_SLOPE_MODE_NO_SLOPES);
 	tone.is_forever = true;
 	tone.debug_id = 'f';
 	const cw_ret_t cwret2 = cw_tq_enqueue_internal(gen->tq, &tone);
-	cte->expect_op_int(cte, CW_SUCCESS, "==", cwret2, "enqueue forever tone");
+	(*pass) = cte->expect_op_int(cte, CW_SUCCESS, "==", cwret2, "enqueue forever tone") && (*pass);
 
 #ifdef __FreeBSD__  /* Tested on FreeBSD 10. */
 	/* Separate path for FreeBSD because for some reason signals
@@ -637,7 +613,7 @@ static cwt_retv test_cw_gen_forever_sub(cw_test_executor_t * cte, __attribute__(
 	CW_TONE_INIT(&tone, freq, slope_duration, CW_SLOPE_MODE_FALLING_SLOPE);
 	tone.debug_id = 'e';
 	const cw_ret_t cwret3 = cw_tq_enqueue_internal(gen->tq, &tone);
-	cte->expect_op_int(cte, CW_SUCCESS, "==", cwret3, "silence the generator");
+	(*pass) = cte->expect_op_int(cte, CW_SUCCESS, "==", cwret3, "silence the generator") && (*pass);
 
 	cw_gen_wait_for_queue_level(gen, 0);
 	cw_gen_wait_for_end_of_current_tone(gen);
@@ -645,61 +621,7 @@ static cwt_retv test_cw_gen_forever_sub(cw_test_executor_t * cte, __attribute__(
 	cw_gen_stop(gen);
 	cw_gen_delete(&gen);
 
-	return cwt_retv_ok;
-}
-
-
-
-
-/**
-   @reviewed on 2020-05-07
-*/
-cwt_retv test_cw_gen_get_timing_parameters_internal(cw_test_executor_t * cte)
-{
-	cte->print_test_header(cte, __func__);
-
-	int initial = -5;
-
-	int dot_duration = initial;
-	int dash_duration = initial;
-	int ims_duration = initial;
-	int ics_duration = initial;
-	int iws_duration = initial;
-	int additional_space_duration = initial;
-	int adjustment_space_duration = initial;
-
-	cw_gen_t * gen = cw_gen_new(&cte->current_gen_conf);
-	cw_gen_start(gen);
-
-
-	cw_gen_reset_parameters_internal(gen);
-	/* Reset requires resynchronization. */
-	cw_gen_sync_parameters_internal(gen);
-
-
-	LIBCW_TEST_FUT(cw_gen_get_timing_parameters_internal)(gen,
-							      &dot_duration,
-							      &dash_duration,
-							      &ims_duration,
-							      &ics_duration,
-							      &iws_duration,
-							      &additional_space_duration,
-							      &adjustment_space_duration);
-
-	bool failure = (dot_duration == initial)
-		|| (dash_duration == initial)
-		|| (ims_duration == initial)
-		|| (ics_duration == initial)
-		|| (iws_duration == initial)
-		|| (additional_space_duration == initial)
-		|| (adjustment_space_duration == initial);
-	cte->expect_op_int(cte, false, "==", failure, "get timing parameters");
-
-	cw_gen_delete(&gen);
-
-	cte->print_test_footer(cte, __func__);
-
-	return cwt_retv_ok;
+	return 0;
 }
 
 
@@ -1009,7 +931,7 @@ cwt_retv test_cw_gen_enqueue_primitives(cw_test_executor_t * cte)
 	cte->print_test_header(cte, "%s (%d)", __func__, loops);
 
 	cw_gen_t * gen = NULL;
-	if (cwt_retv_ok != gen_setup(cte, &gen)) {
+	if (0 != gen_setup(cte, &gen)) {
 		cte->log_error(cte, "%s:%d: Failed to create generator\n", __func__, __LINE__);
 		return cwt_retv_err;
 	}
@@ -1055,7 +977,7 @@ cwt_retv test_cw_gen_enqueue_primitives(cw_test_executor_t * cte)
 			/* TODO: this function adds 2-Unit space, not a
 			   regular 3-Unit inter-character-space. Be aware of
 			   this fact. */
-			const cw_ret_t cwret = LIBCW_TEST_FUT(cw_gen_enqueue_2u_ics_internal)(gen);
+			const cw_ret_t cwret = LIBCW_TEST_FUT(cw_gen_enqueue_ics_internal)(gen);
 			if (!cte->expect_op_int_errors_only(cte, CW_SUCCESS, "==", cwret, "enqueue ics internal() (i = %d)", i)) {
 				failure = true;
 				break;
@@ -1108,7 +1030,7 @@ cwt_retv test_cw_gen_enqueue_representations(cw_test_executor_t * cte)
 	   representation represents a supported character. */
 
 	cw_gen_t * gen = NULL;
-	if (cwt_retv_ok != gen_setup(cte, &gen)) {
+	if (0 != gen_setup(cte, &gen)) {
 		cte->log_error(cte, "%s:%d: Failed to create generator\n", __func__, __LINE__);
 		return cwt_retv_err;
 	}
@@ -1195,7 +1117,7 @@ cwt_retv test_cw_gen_enqueue_character(cw_test_executor_t * cte)
 	cte->print_test_header(cte, "%s (%d)", __func__, loops);
 
 	cw_gen_t * gen = NULL;
-	if (cwt_retv_ok != gen_setup(cte, &gen)) {
+	if (0 != gen_setup(cte, &gen)) {
 		cte->log_error(cte, "%s:%d: Failed to create generator\n", __func__, __LINE__);
 		return cwt_retv_err;
 	}
@@ -1272,7 +1194,7 @@ cwt_retv test_cw_gen_enqueue_string(cw_test_executor_t * cte)
 	cte->print_test_header(cte, "%s (%d)", __func__, loops);
 
 	cw_gen_t * gen = NULL;
-	if (cwt_retv_ok != gen_setup(cte, &gen)) {
+	if (0 != gen_setup(cte, &gen)) {
 		cte->log_error(cte, "%s:%d: Failed to create generator\n", __func__, __LINE__);
 		return cwt_retv_err;
 	}
@@ -1333,54 +1255,3 @@ cwt_retv test_cw_gen_enqueue_string(cw_test_executor_t * cte)
 
 
 
-/**
-   @brief Test removing a character from end of enqueued characters
-
-   @reviewed on 2020-08-24
-*/
-cwt_retv test_cw_gen_remove_last_character(cw_test_executor_t * cte)
-{
-	cte->print_test_header(cte, "%s", __func__);
-
-	cw_gen_t * gen = NULL;
-	if (cwt_retv_ok != gen_setup(cte, &gen)) {
-		cte->log_error(cte, "%s:%d: Failed to create generator\n", __func__, __LINE__);
-		return cwt_retv_err;
-	}
-
-	const int n = 4;
-	bool failure = false;
-	for (int to_remove = 0; to_remove <= n; to_remove++) {
-		cw_gen_start(gen);
-
-		cte->log_info(cte, "You will now hear 'oooo' followed by %d 's' characters\n", n - to_remove);
-		cw_gen_enqueue_string(gen, "oooo" "ssss");
-
-		/* Remove N characters from end. */
-		for (int i = 0; i < to_remove; i++) {
-			cw_ret_t cwret = LIBCW_TEST_FUT(cw_gen_remove_last_character(gen));
-			if (!cte->expect_op_int_errors_only(cte, CW_SUCCESS, "==", cwret,
-							    "remove last %d characters, removing %d-th character",
-							    to_remove, i)) {
-				failure = true;
-				break;
-			}
-		}
-
-		cw_gen_wait_for_queue_level(gen, 0);
-		cw_usleep_internal(1000 * 1000);
-		cw_gen_stop(gen);
-
-		if (failure) {
-			break;
-		}
-	}
-
-	gen_destroy(&gen);
-
-	cte->expect_op_int(cte, false, "==", failure, "remove last character");
-
-	cte->print_test_footer(cte, __func__);
-
-	return cwt_retv_ok;
-}
