@@ -9,6 +9,7 @@
 
 
 
+#include "libcw_gen.h"
 #include "test_framework.h"
 
 
@@ -22,14 +23,12 @@ int test_cw_gen_new_start_stop_delete(cw_test_executor_t * cte);
 int test_cw_gen_set_tone_slope(cw_test_executor_t * cte);
 int test_cw_gen_tone_slope_shape_enums(cw_test_executor_t * cte);
 int test_cw_gen_forever_internal(cw_test_executor_t * cte);
-int test_cw_gen_get_timing_parameters_internal(cw_test_executor_t * cte);
 int test_cw_gen_parameter_getters_setters(cw_test_executor_t * cte);
 int test_cw_gen_volume_functions(cw_test_executor_t * cte);
 int test_cw_gen_enqueue_primitives(cw_test_executor_t * cte);
 int test_cw_gen_enqueue_representations(cw_test_executor_t * cte);
 int test_cw_gen_enqueue_character(cw_test_executor_t * cte);
 int test_cw_gen_enqueue_string(cw_test_executor_t * cte);
-cwt_retv test_cw_gen_remove_last_character(cw_test_executor_t * cte);
 
 
 
