@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -45,6 +45,7 @@
 
 
 
+#include "common.h"
 #include "libcw.h"
 #include "libcw_debug.h"
 #include "libcw_tq.h"
@@ -80,112 +81,7 @@ extern volatile cw_key_t cw_key;
 static void test_helper_tq_callback(void * ptr);
 
 /* Helper function for iambic key tests. */
-static void legacy_api_test_iambic_key_paddles_common(cw_test_executor_t * cte, const int intended_dot_paddle, const int intended_dash_paddle, char character, int n_elements);
-
-static int legacy_api_standalone_test_setup(cw_test_executor_t * cte, bool start_gen);
-static int legacy_api_standalone_test_teardown(__attribute__((unused)) cw_test_executor_t * cte);
-
-
-
-
-/**
-   @brief Setup test environment for a test of legacy function
-
-   @param start_gen whether a prepared generator should be started
-
-   @reviewed on 2020-10-04
-*/
-int legacy_api_standalone_test_setup(cw_test_executor_t * cte, bool start_gen)
-{
-	if (CW_SUCCESS != cw_generator_new(cte->current_gen_conf.sound_system, cte->current_gen_conf.sound_device)) {
-		cte->log_error(cte, "Can't create generator, stopping the test\n");
-		return cwt_retv_err;
-	}
-	if (start_gen) {
-		if (CW_SUCCESS != cw_generator_start()) {
-			cte->log_error(cte, "Can't start generator, stopping the test\n");
-			cw_generator_delete();
-			return cwt_retv_err;
-		}
-	}
-
-	cw_reset_send_receive_parameters();
-	cw_set_send_speed(30);
-	cw_set_receive_speed(30);
-	cw_disable_adaptive_receive();
-	cw_reset_receive_statistics();
-	cw_unregister_signal_handler(SIGUSR1);
-	errno = 0;
-
-	return cwt_retv_ok;
-}
-
-
-
-
-/**
-   @brief Deconfigure test environment after running a test of legacy function
-
-   @reviewed on 2020-10-04
-*/
-int legacy_api_standalone_test_teardown(__attribute__((unused)) cw_test_executor_t * cte)
-{
-	sleep(1);
-	cw_generator_stop();
-	sleep(1);
-	cw_generator_delete();
-
-	return 0;
-}
-
-
-
-
-/**
-   @reviewed on 2019-10-13
-*/
-int legacy_api_test_low_level_gen_parameters(cw_test_executor_t * cte)
-{
-	cte->print_test_header(cte, __func__);
-	legacy_api_standalone_test_setup(cte, true);
-
-	int txdot_usecs = -1;
-	int txdash_usecs = -1;
-	int end_of_element_usecs = -1;
-	int end_of_character_usecs = -1;
-	int end_of_word_usecs = -1;
-	int additional_usecs = -1;
-	int adjustment_usecs = -1;
-
-	/* Print and verify default low level timing values. */
-	cw_reset_send_receive_parameters();
-	LIBCW_TEST_FUT(cw_get_send_parameters)(&txdot_usecs, &txdash_usecs,
-					       &end_of_element_usecs, &end_of_character_usecs,
-					       &end_of_word_usecs, &additional_usecs,
-					       &adjustment_usecs);
-	cte->log_info(cte,
-		      "cw_get_send_parameters():\n"
-		      "    %d, %d, %d, %d, %d, %d, %d\n",
-		      txdot_usecs, txdash_usecs, end_of_element_usecs,
-		      end_of_character_usecs,end_of_word_usecs, additional_usecs,
-		      adjustment_usecs);
-
-	cte->expect_op_int(cte, txdot_usecs,            ">=", 0, "send parameters: txdot_usecs");
-	cte->expect_op_int(cte, txdash_usecs,           ">=", 0, "send parameters: txdash_usecs");
-	cte->expect_op_int(cte, end_of_element_usecs,   ">=", 0, "send parameters: end_of_element_usecs");
-	cte->expect_op_int(cte, end_of_character_usecs, ">=", 0, "send parameters: end_of_character_usecs");
-	cte->expect_op_int(cte, end_of_word_usecs,      ">=", 0, "send parameters: end_of_word_usecs");
-	cte->expect_op_int(cte, additional_usecs,       ">=", 0, "send parameters: additional_usecs");
-	cte->expect_op_int(cte, adjustment_usecs,       ">=", 0, "send parameters: adjustment_usecs");
-
-	legacy_api_standalone_test_teardown(cte);
-	cte->print_test_footer(cte, __func__);
-
-	return 0;
-}
-
-
-
+static void legacy_api_test_iambic_key_paddles_common(cw_test_executor_t * cte, int intended_dot_paddle, int intended_dash_paddle, char character, int n_elements);
 
 /**
    @reviewed on 2019-10-13
@@ -347,7 +243,8 @@ int legacy_api_test_cw_wait_for_tone(cw_test_executor_t * cte)
 	{
 		cw_set_volume(70);
 
-		int freq_min, freq_max;
+		int freq_min;
+		int freq_max;
 		cw_get_frequency_limits(&freq_min, &freq_max);
 		const int delta_freq = ((freq_max - freq_min) / (n_tones_to_add - 1));      /* Delta of frequency in loops. */
 
@@ -459,7 +356,8 @@ int legacy_api_test_cw_wait_for_tone_queue(cw_test_executor_t * cte)
 	{
 		cw_set_volume(70);
 
-		int freq_min, freq_max;
+		int freq_min;
+		int freq_max;
 		cw_get_frequency_limits(&freq_min, &freq_max);
 		const int delta_freq = ((freq_max - freq_min) / (n_tones_to_add - 1));
 
@@ -538,7 +436,8 @@ int legacy_api_test_cw_queue_tone(cw_test_executor_t * cte)
 	cw_set_volume(70);
 	int duration = 20000;
 
-	int freq_min, freq_max;
+	int freq_min;
+	int freq_max;
 	cw_get_frequency_limits(&freq_min, &freq_max);
 	const int freq_delta = 10;
 
@@ -794,7 +693,7 @@ int legacy_api_test_tone_queue_callback(cw_test_executor_t * cte)
 		   that captured level may be in a range of values. */
 		const int expected_lower = level - 1;
 		const int expected_higher = level;
-		cte->expect_between_int(cte, expected_lower, data.captured_level, expected_higher, "tone queue callback:           level at callback = %d", data.captured_level);
+		cte->expect_between_int(cte, expected_lower, data.captured_level, expected_higher, "tone queue callback: level at callback = %d", data.captured_level);
 
 		cw_reset_tone_queue();
 	}
@@ -832,6 +731,12 @@ static void test_helper_tq_callback(void * ptr)
    Fill tone queue with short tones, then check that we can move the
    volume through its entire range.  Flush the queue when complete.
 
+   TODO acerion 2023.11.02: make the test more similar to
+   test_cw_gen_volume_functions().
+
+   TODO acerion 2023.11.02: move tests of test_cw_gen_volume_functions() to
+   separate test function. Mark the test function as "quick test".
+
    @reviewed on 2019-10-13
 */
 int legacy_api_test_volume_functions(cw_test_executor_t * cte)
@@ -841,7 +746,10 @@ int legacy_api_test_volume_functions(cw_test_executor_t * cte)
 
 	int vol_min = -1;
 	int vol_max = -1;
-	const int vol_delta = 5;
+
+	/* '5' was too large: test was too short and I was not able to fully
+	   confirm changes to volume. */
+	const int vol_delta = 2;
 
 	/* Test: get range of allowed volumes. */
 	{
@@ -1703,7 +1611,7 @@ cwt_retv legacy_api_test_gen_remove_last_character(cw_test_executor_t * cte)
 
 		/* Remove N characters from end. */
 		for (int i = 0; i < to_remove; i++) {
-			cw_ret_t cwret = LIBCW_TEST_FUT(cw_generator_remove_last_character());
+			cw_ret_t cwret = LIBCW_TEST_FUT(cw_generator_remove_last_character)();
 			if (!cte->expect_op_int_errors_only(cte, CW_SUCCESS, "==", cwret,
 							    "remove last %d characters, removing %d-th character",
 							    to_remove, i)) {
@@ -1723,7 +1631,7 @@ cwt_retv legacy_api_test_gen_remove_last_character(cw_test_executor_t * cte)
 
 		   Some cases of buffer underrun have been fixed with calls
 		   to snd_pcm_drain(), but perhaps not all of them. */
-		cw_usleep_internal(1000 * 1000);
+		cw_usleep_internal(1 * CW_USECS_PER_SEC);
 
 		if (failure) {
 			break;
