@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,12 +31,11 @@
 
 
 
+#include <cwutils/lib/random.h>
+
 #include "libcw.h"
 #include "libcw2.h"
 
-
-
-
 #include "libcw_debug.h"
 #include "libcw_key.h"
 #include "libcw_rec.h"
@@ -63,9 +62,6 @@ typedef struct cw_variation_params {
 	/* For functions generating varying send speeds. */
 	int speed_min;
 	int speed_max;
-
-	/* For... something. */
-	int fuzz_percent;
 } cw_variation_params;
 
 
@@ -270,7 +266,7 @@ int test_cw_rec_test_with_constant_speeds(cw_test_executor_t * cte)
 	while (test_data[i].name) {
 		for (int speed = CW_SPEED_MIN; speed <= CW_SPEED_MAX; speed++) {
 
-			const cw_variation_params variation_params = { .speed = speed, .speed_min = 0, .speed_max = 0, .fuzz_percent = 0 };
+			const cw_variation_params variation_params = { .speed = speed, .speed_min = 0, .speed_max = 0 };
 
 			/* Generate duration data for given list of
 			   characters, each character is sent with
@@ -291,7 +287,7 @@ int test_cw_rec_test_with_constant_speeds(cw_test_executor_t * cte)
 			/* Verify that the test speed has been set correctly. */
 			const float rec_speed = cw_rec_get_speed(rec);
 			const float diff = rec_speed - speed;
-			cte->assert2(cte, diff < 0.1f, "%s: setting speed for test %s failed: %.3f != %.3f\n",
+			cte->assert2(cte, fabsf(diff) < 0.1f, "%s: setting speed for test %s failed: %.3f != %.3f\n",
 				     this_test_name, test_data[i].name,
 				     /* Casting to double to avoid compiler warning about implicit conversion from float to double. */
 				     (double) rec_speed, (double) speed);
@@ -355,7 +351,7 @@ int test_cw_rec_test_with_varying_speeds(cw_test_executor_t * cte)
 	int i = 0;
 	while (test_data[i].name) {
 
-		cw_variation_params variation_params = { .speed = 0, .speed_min = CW_SPEED_MIN, .speed_max = CW_SPEED_MAX, .fuzz_percent = 0 };
+		cw_variation_params variation_params = { .speed = 0, .speed_min = CW_SPEED_MIN, .speed_max = CW_SPEED_MAX };
 
 		/* Generate duration data for given set of characters, each
 		   character is sent with varying speed from range
@@ -378,7 +374,7 @@ int test_cw_rec_test_with_varying_speeds(cw_test_executor_t * cte)
 		/* Verify that initial test speed has been set correctly. */
 		const float rec_speed = cw_rec_get_speed(rec);
 		const float diff = rec_speed - CW_SPEED_MAX;
-		cte->assert2(cte, diff < 0.1f, "%s: incorrect receive speed: %.3f != %.3f\n",
+		cte->assert2(cte, fabsf(diff) < 0.5f, "%s: incorrect receive speed: %.3f != %.3f\n",
 			     this_test_name,
 			     /* Casting to double to avoid compiler warning about implicit conversion from float to double. */
 			     (double) rec_speed, (double) CW_SPEED_MAX);
@@ -711,7 +707,9 @@ cw_characters_list * cw_characters_list_new_basic(cw_test_executor_t * cte)
 */
 cw_characters_list * cw_characters_list_new_random(cw_test_executor_t * cte)
 {
-	const size_t n_random_characters = cw_get_character_count() * ((lrand48() % 50) + 30);
+	int x_random = 0;
+	cw_random_get_int(30, 80, &x_random);
+	const size_t n_random_characters = cw_get_character_count() * x_random;
 
 	/* We will use basic characters list (all characters supported
 	   by libcw) as an input for generating random characters
@@ -727,12 +725,13 @@ cw_characters_list * cw_characters_list_new_random(cw_test_executor_t * cte)
 	cte->assert2(cte, random_characters_list->values, "second calloc() failed\n");
 
 
-	size_t space_randomizer = 3;
+	uint32_t space_randomizer = 3;
 	for (size_t i = 0; i < n_random_characters; i++) {
-		int basic_idx = lrand48() % n_basic_characters;
+		uint32_t basic_idx = 0;
+		cw_random_get_uint32(0, n_basic_characters - 1, &basic_idx);
 
 		if (0 == (basic_idx % space_randomizer)) { /* Insert space at random places. */
-			space_randomizer = (lrand48() % (n_basic_characters / 2)) + 3; /* Pick new value for next round. */
+			cw_random_get_uint32(3, (n_basic_characters / 2) + 3, &space_randomizer); /* Pick new value for next round. */
 			random_characters_list->values[i] = ' ';
 
 			/*
@@ -983,12 +982,23 @@ cw_rec_test_vector * cw_rec_test_vector_factory(cw_test_executor_t * cte, charac
 			   space). We want to turn inter-character-space
 			   of previous point into inter-word-space,
 			   hence 'out_idx - 1'. */
-			cw_rec_test_point * prev_point = vec->points[out_idx - 1];
-			const int space_idx = prev_point->n_tone_durations - 1;   /* Index of last space (inter-character-space, to become inter-word-space). */
-			prev_point->tone_durations[space_idx] = dot_duration * 6; /* dot_duration * 5 is the minimal inter-word-space. */
-			prev_point->is_last_in_word = true;
+			if (out_idx == 0) {
+				/*
+				  There is no 'previous point' yet! We can't turn any ics into iws.
 
-			continue;
+				  TODO acerion 2023.09.02: how to handle this case? Perhaps
+				  this situation may occur when input string starts with
+				  space.
+				*/
+				kite_log(cte, LOG_WARNING, "Unexpected condition: out_idx == 0\n");
+			} else {
+				cw_rec_test_point * prev_point = vec->points[out_idx - 1];
+				const int space_idx = prev_point->n_tone_durations - 1;   /* Index of last space (inter-character-space, to become inter-word-space). */
+				prev_point->tone_durations[space_idx] = dot_duration * 6; /* dot_duration * 5 is the minimal inter-word-space. */
+				prev_point->is_last_in_word = true;
+
+				continue;
+			}
 		} else {
 			/* A regular character, handled below. */
 		}
@@ -1403,7 +1413,7 @@ int test_cw_rec_parameter_getters_setters_1(cw_test_executor_t * cte)
 
 			const float readback_value = test_data[i].get_value(rec);
 			const float diff = readback_value - new_val;
-			if (!cte->expect_op_float_errors_only(cte, 0.01, ">", diff, "%s: setting %s value in-range: %d (val)", this_test_name, test_data[i].name, new_val)) {
+			if (!cte->expect_op_float_errors_only(cte, 0.01, ">", fabsf(diff), "%s: setting %s value in-range: %d (val)", this_test_name, test_data[i].name, new_val)) {
 				set_ok_failure = true;
 				break;
 			}
