@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,12 +31,12 @@
 
 
 
+#include <cwutils/lib/random.h>
+
 #include "libcw.h"
 #include "libcw2.h"
 
-
-
-
+#include "common.h"
 #include "libcw_utils.h"
 #include "libcw_tq.h"
 #include "libcw_tq_internal.h"
@@ -56,8 +56,6 @@ static int test_cw_tq_enqueue_internal(cw_test_executor_t * cte, cw_tone_queue_t
 static int test_cw_tq_dequeue_internal(cw_test_executor_t * cte, cw_tone_queue_t * tq);
 
 
-static void gen_setup(cw_test_executor_t * cte, cw_gen_t ** gen);
-static void gen_destroy(cw_gen_t ** gen);
 static void enqueue_tone_low_level(cw_test_executor_t * cte, cw_tone_queue_t * tq, const cw_tone_t * tone);
 static cw_tone_queue_t * test_cw_tq_capacity_test_init(cw_test_executor_t * cte, size_t capacity, size_t high_water_mark, int head_shift);
 static void test_helper_tq_callback(void * data);
@@ -66,33 +64,6 @@ static cwt_retv test_helper_fill_queue(cw_test_executor_t * cte, cw_tone_queue_t
 
 
 
-static void gen_setup(cw_test_executor_t * cte, cw_gen_t ** gen)
-{
-	*gen = cw_gen_new(&cte->current_gen_conf);
-	if (!*gen) {
-		cte->log_error(cte, "Can't create generator, stopping the test\n");
-		return;
-	}
-
-	cw_gen_reset_parameters_internal(*gen);
-	cw_gen_sync_parameters_internal(*gen);
-	cw_gen_set_speed(*gen, 30);
-	cw_gen_set_volume(*gen, 70);
-
-	return;
-}
-
-
-
-
-static void gen_destroy(cw_gen_t ** gen)
-{
-	cw_gen_delete(gen);
-}
-
-
-
-
 /**
    @reviewed on 2019-10-03
 */
@@ -174,8 +145,9 @@ int test_cw_tq_capacity_internal(cw_test_executor_t * cte)
 		/* This is a silly test, but let's have any test of
 		   the getter. TODO: come up with better test. */
 
-		const size_t intended_capacity = (lrand48() % 4000) + 10;
-		tq->capacity = intended_capacity;
+		uint32_t intended_capacity = 0;
+		cw_random_get_uint32(10, 4000, &intended_capacity);
+		tq->capacity = (size_t) intended_capacity;
 
 		const size_t readback_capacity = LIBCW_TEST_FUT(cw_tq_capacity_internal)(tq);
 		if (!cte->expect_op_int_errors_only(cte, intended_capacity, "==", readback_capacity, "getting tone queue capacity")) {
@@ -204,7 +176,10 @@ int test_cw_tq_prev_index_internal(cw_test_executor_t * cte)
 	cte->print_test_header(cte, __func__);
 
 	cw_tone_queue_t * tq = cw_tq_new_internal();
-	cte->assert2(cte, NULL != tq, "failed to create new tone queue");
+	if (NULL == tq) {
+		kite_log(cte, LOG_ERR, "failed to create new tone queue");
+		return -1;
+	}
 
 	struct {
 		size_t current_index;
@@ -262,7 +237,10 @@ int test_cw_tq_next_index_internal(cw_test_executor_t * cte)
 	cte->print_test_header(cte, __func__);
 
 	cw_tone_queue_t * tq = cw_tq_new_internal();
-	cte->assert2(cte, NULL != tq, "failed to create new tone queue");
+	if (NULL == tq) {
+		kite_log(cte, LOG_ERR, "failed to create new tone queue");
+		return -1;
+	}
 
 	struct {
 		size_t current_index;
@@ -703,7 +681,9 @@ int test_cw_tq_test_capacity_A(cw_test_executor_t * cte)
 	/* We don't need to check tq with capacity ==
 	   CW_TONE_QUEUE_CAPACITY_MAX (yet). Let's test a smaller
 	   queue capacity. */
-	const size_t capacity = (lrand48() % 40) + 30;
+	uint32_t x_random = 0;
+	cw_random_get_uint32(30, 70, &x_random);
+	const size_t capacity = (size_t) x_random;
 	const size_t watermark = capacity - (capacity * 0.2);
 
 	cte->print_test_header(cte, "%s (%zu)", __func__, capacity);
@@ -820,7 +800,9 @@ int test_cw_tq_test_capacity_B(cw_test_executor_t * cte)
 	/* We don't need to check tq with capacity ==
 	   CW_TONE_QUEUE_CAPACITY_MAX (yet). Let's test a smaller
 	   queue. */
-	const size_t capacity = (lrand48() % 40) + 30;
+	uint32_t x_random = 0;
+	cw_random_get_uint32(30, 70, &x_random);
+	const size_t capacity = (size_t) x_random;
 	const size_t watermark = capacity - (capacity * 0.2);
 
 	cte->print_test_header(cte, "%s", __func__);
@@ -1028,7 +1010,8 @@ cwt_retv test_cw_tq_enqueue_internal_tone_validity(cw_test_executor_t * cte)
 	cw_ret_t cwret;
 
 
-	int freq_min, freq_max;
+	int freq_min;
+	int freq_max;
 	cw_get_frequency_limits(&freq_min, &freq_max);
 
 
@@ -1147,7 +1130,8 @@ cwt_retv test_cw_tq_wait_for_level_internal(cw_test_executor_t * cte)
 		/* Notice that level is always smaller than number of
 		   items added to queue. TODO: reconsider if we want
 		   to randomize this value. */
-		const int level = lrand48() % (int) (floorf(0.7F * loops));
+		int level = 0;
+		cw_random_get_int(0, (int) (floorf(0.7F * loops)), &level);
 		const cw_ret_t cwret = LIBCW_TEST_FUT(cw_tq_wait_for_level_internal)(gen->tq, level);
 		if (!cte->expect_op_int_errors_only(cte, CW_SUCCESS, "==", cwret, "wait for level = %d, tone queue items count = %d", level, loops)) {
 			wait_failure = true;
@@ -1208,10 +1192,14 @@ int test_cw_tq_gen_operations_A(cw_test_executor_t * cte)
 	cte->print_test_header(cte, "%s (%d)", __func__, loops);
 
 	cw_gen_t * gen = NULL;
-	gen_setup(cte, &gen);
+	if (0 != gen_setup(cte, &gen)) {
+		cte->log_error(cte, "%s:%d: Failed to create generator\n", __func__, __LINE__);
+		return -1;
+	}
 	/* Notice that we start the generator later. */
 
-	int freq_min, freq_max;
+	int freq_min;
+	int freq_max;
 	cw_get_frequency_limits(&freq_min, &freq_max);
 
 	const int duration = 100000;  /* Duration of tone. */
@@ -1375,9 +1363,13 @@ int test_cw_tq_gen_operations_A(cw_test_executor_t * cte)
 int test_cw_tq_gen_operations_B(cw_test_executor_t * cte)
 {
 	cw_gen_t * gen = NULL;
-	gen_setup(cte, &gen);
+	if (0 != gen_setup(cte, &gen)) {
+		cte->log_error(cte, "%s:%d: Failed to create generator\n", __func__, __LINE__);
+		return -1;
+	}
 	const size_t capacity = cw_tq_capacity_internal(gen->tq);
-	const int level = lrand48() % (capacity / 2);
+	int level = 0;
+	cw_random_get_int(0, (capacity / 2), &level);
 
 
 	cte->print_test_header(cte, "%s (%d)", __func__, level);
@@ -1385,7 +1377,8 @@ int test_cw_tq_gen_operations_B(cw_test_executor_t * cte)
 
 	const int duration = 4000;
 
-	int freq_min, freq_max;
+	int freq_min;
+	int freq_max;
 	cw_get_frequency_limits(&freq_min, &freq_max);
 	const int freq_delta = 1;
 
@@ -1669,7 +1662,10 @@ int test_cw_tq_callback(cw_test_executor_t * cte)
 
 	for (int i = 1; i < loops; i++) { /* TODO: the test doesn't work for i == 0. This needs to be communicated in documentation. */
 
-		gen_setup(cte, &gen);
+		if (0 != gen_setup(cte, &gen)) {
+			cte->log_error(cte, "%s:%d: Failed to create generator in iteration %d\n", __func__, __LINE__, i);
+			return -1;
+		}
 
 		struct cw_callback_struct test_data;
 		memset(&test_data, 0, sizeof (test_data));
