@@ -11,6 +11,7 @@
 
 #include <stdbool.h>
 #include <stdio.h>
+#include <syslog.h> /* For log severity values (LOG_DEBUG etc.) */
 
 
 
@@ -20,13 +21,14 @@
 
 
 
-#include <cw_common.h>
+#include <cwutils/cw_common.h>
 #include <libcw.h>
 
 
 
 
-#include "test_framework_tools.h"
+#include <test_framework/basic_utils/test_result.h>
+#include <test_framework/basic_utils/resource_meas.h>
 
 
 
@@ -71,10 +73,45 @@ struct cw_test_set_t;
 
 
 
+typedef struct sound_system_config_t {
+	//cw_sound_system_t sound_system;
+
+	/**
+	   Whether a sound system should be tested in current session of test
+	   executor (i.e. during current tests).
+
+	   Sound system may be inactive because it wasn't requested (implicitly
+	   or explicitly) in command line, or because given sound system is not
+	   available on current machine.
+	*/
+	bool active;
+
+	char sound_device[LIBCW_SOUND_DEVICE_NAME_SIZE];
+} sound_system_config_t;
+
+
+
+
+/**
+   @brief Configuration of tests that shall be executed.
+*/
+typedef struct tests_configuration_t {
+	/* Array indexed with distinct CW_AUDIO_* values. CW_AUDIO_SOUNDCARD is
+	   NOT a distinct value. */
+	sound_system_config_t sound_systems[CW_SOUND_SYSTEM_LAST + 1];
+
+	/* List with varying length of added topics. */
+	int topics[LIBCW_TEST_TOPIC_MAX + 1];
+} tests_configuration_t;
+
+
+
+
 struct cw_test_executor_t;
 typedef struct cw_test_executor_t {
 
-	cw_config_t * config;
+	cw_config_t * config; /* Command line options. */
+	tests_configuration_t configuration; /* Configuration of tests. Test executor should follow this configuration. */
 
 	char msg_prefix[32];
 
@@ -94,8 +131,16 @@ typedef struct cw_test_executor_t {
 	long uptime_end;
 #endif
 
-	/* Type suitable for srand48(). */
-	long int random_seed;
+	/*
+	  With my current method of generating random seed (see
+	  cwutils/lib/random.c) I could barely generate slightly above 32 random
+	  bits of seed. Therefore 32 bits should suffice for now.
+
+	  srand() expects 'unsigned int' seed, i.e. 4 bytes.
+	  srandom() expects 'unsigned int' seed, i.e. 4 bytes.
+	  srand48() expects 'long' seed, i.e. 8 bytes :(
+	*/
+	uint32_t random_seed;
 
 	/*
 	  Sound system and test topic currently tested.  Should be set right
@@ -106,7 +151,7 @@ typedef struct cw_test_executor_t {
 	int current_topic;
 
 	/* Limit of characters that can be printed to console in one row. */
-	int console_n_cols;
+	int console_n_cols; /* TODO acerion 2023.11.04: consider making it size_t instead of int. */
 
 	/* This array holds stats for all distinct sound systems, and
 	   is indexed by cw_audio_systems enum. This means that first
@@ -139,16 +184,19 @@ typedef struct cw_test_executor_t {
 
 	   You shouldn't put newline character at end of formatting
 	   string. The messages printed by these functions will be followed
-	   by "[ OK ]" or "[FAIL]" tags, and the newline would put these tags
+	   by "[PASS]" or "[FAIL]" tags, and the newline would put these tags
 	   in new line, decreasing readability of test results.
 
-	   @return true if this comparison shows that the values satisfy the operator
+	   @return true if tested value and expected value satisfy given operator (i.e. test passes)
 	   @return false otherwise
 	*/
 	bool (* expect_op_int)(struct cw_test_executor_t * self, int expected_value, const char * operator, int received_value, const char * fmt, ...) __attribute__ ((format (printf, 5, 6)));
 	bool (* expect_op_int_errors_only)(struct cw_test_executor_t * self, int expected_value, const char * operator, int received_value, const char * fmt, ...) __attribute__ ((format (printf, 5, 6)));
 	bool (* expect_op_float)(struct cw_test_executor_t * self, float expected_value, const char * operator, float received_value, const char * fmt, ...) __attribute__ ((format (printf, 5, 6)));
 	bool (* expect_op_float_errors_only)(struct cw_test_executor_t * self, float expected_value, const char * operator, float received_value, const char * fmt, ...) __attribute__ ((format (printf, 5, 6)));
+	bool (* expect_op_double)(struct cw_test_executor_t * self, double expected_value, const char * operator, double received_value, const char * fmt, ...) __attribute__ ((format (printf, 5, 6)));
+	bool (* expect_op_double_errors_only)(struct cw_test_executor_t * self, double expected_value, const char * operator, double received_value, const char * fmt, ...) __attribute__ ((format (printf, 5, 6)));
+	bool (* expect_strcasecmp)(struct cw_test_executor_t * self, const char * expected_value, const char * received_value, const char * fmt, ...) __attribute__ ((format (printf, 4, 5)));
 
 	/**
 	   Verify that @param received_value is between @param
@@ -264,10 +312,10 @@ typedef struct cw_test_executor_t {
 	   Function exits with EXIT_SUCCESS status when "help" option
 	   was requested. Help text is printed before the exit.
 
-	   @return cwt_retv_ok on success
-	   @return cwt_retv_err otherwise
+	   @return 0 on success
+	   @return -1 otherwise
 	*/
-	cwt_retv (* process_args)(struct cw_test_executor_t * self, int argc, char * const argv[]);
+	int (* process_args)(struct cw_test_executor_t * self, int argc, char * const argv[]);
 
 
 	/**
@@ -330,20 +378,18 @@ typedef struct cw_test_executor_t {
 	const char * (* get_current_sound_device)(struct cw_test_executor_t * self);
 
 
-
-
 	/**
-	   Log information to cw_test_executor_t::stdout file (if it is set).
+	   Log information to cw_test_executor_t::file_out file (if it is set).
 	   Add "[II]" mark at the beginning.
 	   Add message prefix at the beginning.
 	   Don't add newline character at the end.
 
 	   @return number of characters printed
 	*/
-        int (* log_info)(struct cw_test_executor_t * self, const char * fmt, ...) __attribute__ ((format (printf, 2, 3)));
+	int (* log_info)(struct cw_test_executor_t * self, const char * fmt, ...) __attribute__ ((format (printf, 2, 3)));
 
 	/**
-	   Log text to cw_test_executor_t::stdout file (if it is set).
+	   Log text to cw_test_executor_t::file_out file (if it is set).
 	   Don't add "[II]" mark at the beginning.
 	   Don't add message prefix at the beginning.
 	   Don't add newline character at the end.
@@ -356,34 +402,12 @@ typedef struct cw_test_executor_t {
 	void (* flush_info)(struct cw_test_executor_t * self);
 
 	/**
-	   Log error to cw_test_executor_t::stdout file (if it is set).
+	   Log error to cw_test_executor_t::file_out file (if it is set).
 	   Add "[EE]" mark at the beginning.
 	   Add message prefix at the beginning.
 	   Don't add newline character at the end.
 	*/
 	void (* log_error)(struct cw_test_executor_t * self, const char * fmt, ...) __attribute__ ((format (printf, 2, 3)));
-
-	/**
-	   See whether or not a given test topic was requested from
-	   command line. By default, if not specified in command line,
-	   all test topics are requested.
-	*/
-	bool (* test_topic_was_requested)(struct cw_test_executor_t * self, int libcw_test_topic);
-
-	/**
-	   See whether or not a given sound system was requested from
-	   command line. By default, if not specified in command line,
-	   all sound systems are requested.
-
-	   However, if a host machine does not support some sound
-	   system (e.g. because a library is missing), such sound
-	   system is excluded from list of requested sound systems.
-	*/
-	bool (* sound_system_was_requested)(struct cw_test_executor_t * self, cw_sound_system sound_system);
-
-
-
-
 	/**
 	   @brief Main test loop that walks through given @param
 	   @test_sets and executes all test function specified in
@@ -410,6 +434,28 @@ typedef struct cw_test_executor_t {
 
 
 
+/**
+   @brief Log message with given severity to cw_test_executor_t::file_out file (if it is set)
+
+   Prepend the message with severity string/mark that matches @p severity.
+
+   Use syslog's severity level values (LOG_ERR, LOG_INFO, etc) as values of
+   @p severity. Only values in range of LOG_DEBUG - LOG_ERR (inclusive) are
+   supported.
+
+   The function doesn't append its own newline character at the end.
+
+   @param[in/out] executor Test executor
+   @param[in] severity Severity level (e.g. LOG_ERR, LOG_INFO)
+   @param[in] fmt Format string of message
+
+   @return Number of characters printed. Zero may (but doesn't have to) indicate an error.
+*/
+size_t kite_log(struct cw_test_executor_t * executor, int severity, const char * fmt, ...) __attribute__ ((format (printf, 3, 4)));
+
+
+
+
 /**
    @brief Initialize cw_text_executor_t object @param cte
 
@@ -424,6 +470,33 @@ void cw_test_init(cw_test_executor_t * self, FILE * stdout, FILE * stderr, const
 
 
 
+/**
+   @brief Take actions at end of single test
+
+   Call the function at the very end of test function to display indication
+   that test function with name @param function_name has completed its work.
+   Also display PASS/FAIL status depending on value of @p test_result.
+
+   Update counters of test successes/failures in @p kite according to value
+   of @p test_result.
+
+   TODO acerion 2023.11.04: use this function in all tests. The function
+   should present test result in consistent way for all tests, and should be
+   the only function that is incrementing counters of test
+   successes/failures. The increment should be removed from all other
+   functions: only this function should be doing the incrementing.
+
+   @reviewedon 2023.11.04
+
+   @param[in/out] kite Test executor
+   @param[in] test_name Name of test that has just completed
+   @param[in] test_result Result of the completed test
+*/
+void kite_on_test_completion(cw_test_executor_t * kite, const char * test_name, test_result_t test_result);
+
+
+
+
 /**
    @brief Deinitialize cw_test_executor_t object @param cte
 */
@@ -489,7 +562,7 @@ typedef struct cw_test_set_t {
 /* At what intervals the CPU usage will be measured. */
 #define LIBCW_TEST_MEAS_CPU_MEAS_INTERVAL_MSECS 200
 
-/* What is the top CPU usage threshold during test function's execution. */
+/* What is the top allowed CPU usage threshold during test function's execution [percent]. */
 #define LIBCW_TEST_MEAS_CPU_OK_THRESHOLD_PERCENT 4.0F
 
 
