@@ -1,5 +1,5 @@
 // Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-// Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+// Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -51,12 +51,12 @@
 #include "receiver.h"
 #include "textarea.h"
 #include "modeset.h"
-#include "cw_common.h"
 
-#include "libcw.h"
+#include <libcw.h>
 
-#include "i18n.h"
-#include "cw_copyright.h"
+#include <cwutils/cw_common.h>
+#include <cwutils/i18n.h>
+#include <cwutils/cw_copyright.h>
 
 
 
@@ -306,8 +306,10 @@ void Application::start()
 
 	sender->clear();
 	receiver->clear();
-#ifdef XCWCP_WITH_REC_TEST
-	receiver->start_test_code();
+#ifdef ENABLE_DEV_RECEIVER_TEST
+	if (current_mode()->is_receiver_test()) {
+		receiver->start_test_code();
+	}
 #endif
 
 	/* Accessing proper action through this->startstop should also
@@ -322,10 +324,10 @@ void Application::start()
 
 	clear_status();
 
-	/* At 60WPM, a dot is 20ms, so polling for the maximum speed
-	   library needs a 10ms timeout. */
+	/* This program is polling a receiver for data. Polling happens at
+	   given interval. */
 	poll_timer->setSingleShot(false);
-	poll_timer->start(10);
+	poll_timer->start(CW_REC_MINIMAL_POLL_PERIOD_MSECS);
 
 	return;
 }
@@ -351,8 +353,10 @@ void Application::stop()
 	poll_timer->stop();
 	sender->clear();
 	receiver->clear();
-#ifdef XCWCP_WITH_REC_TEST
-	receiver->stop_test_code();
+#ifdef ENABLE_DEV_RECEIVER_TEST
+	if (current_mode()->is_receiver_test()) {
+		receiver->stop_test_code();
+	}
 #endif
 
 	/* Saving speed for restore on next start. */
@@ -1178,5 +1182,13 @@ void Application::clear_status()
 
 
 
+const Mode * Application::current_mode() const
+{
+	return modeset.get(mode_combo->currentIndex());
+}
+
+
+
 
 }  /* namespace cw */
+
