@@ -1,5 +1,5 @@
 // Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-// Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+// Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -31,9 +31,10 @@
 #include <string>
 #include <deque>
 
-#include "libcw.h"
+#include <libcw.h>
+#include <cwutils/cw_common.h>
+
 #include "modeset.h"
-#include "cw_common.h"
 
 
 
@@ -71,6 +72,8 @@ namespace cw {
 		void show_status(const QString &status);
 		void clear_status();
 
+		const Mode * current_mode() const;
+
 	protected:
 		void closeEvent(QCloseEvent *event);
 
