@@ -1,5 +1,5 @@
 // Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-// Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+// Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 //
 
 #include "modeset.h"
-#include "dictionary.h"
+#include <cwutils/dictionary.h>
 
 
 
@@ -37,7 +37,8 @@ bool Mode::is_same_type_as(const Mode *other) const
 {
 	return (is_dictionary() && other->is_dictionary())
 		|| (is_keyboard() && other->is_keyboard())
-		|| (is_receive() && other->is_receive());
+		|| (is_receive() && other->is_receive())
+		|| (is_receiver_test() && other->is_receiver_test());
 }
 
 
@@ -110,6 +111,12 @@ ModeSetHelper::ModeSetHelper()
 	modes.push_back(new KeyboardMode("Send Keyboard CW"));
 	modes.push_back(new ReceiveMode("Receive Keyed CW"));
 
+#ifdef ENABLE_DEV_RECEIVER_TEST
+	// Use "==" prefix and postfix to make the text more noticeable in modes
+	// drop-down menu.
+	modes.push_back(new ReceiverTestMode("== Run Receiver Test =="));
+#endif
+
 	return;
 }
 
