@@ -1,5 +1,5 @@
 // Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-// Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+// Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -26,7 +26,7 @@
 #include <string>
 #include <vector>
 
-#include "dictionary.h"
+#include <cwutils/dictionary.h>
 
 
 
@@ -41,6 +41,7 @@ namespace cw {
 	class DictionaryMode;
 	class KeyboardMode;
 	class ReceiveMode;
+	class ReceiverTestMode;
 
 
 
@@ -63,6 +64,7 @@ namespace cw {
 		inline virtual bool is_dictionary() const { return false; };
 		inline virtual bool is_keyboard()   const { return false; };
 		inline virtual bool is_receive()    const { return false; };
+		inline virtual bool is_receiver_test()    const { return false; };
 
 		virtual const DictionaryMode *get_dmode() const { return NULL; };
 		virtual const KeyboardMode *get_kmode()   const { return NULL; };
@@ -138,6 +140,26 @@ namespace cw {
 
 
 
+#ifdef ENABLE_DEV_RECEIVER_TEST
+	class ReceiverTestMode : public Mode {
+	public:
+		ReceiverTestMode(const std::string &descr) : Mode (descr) { }
+
+		/* This is also a receive mode. In this mode we receive
+		   events from test generator, not from keyboard or mouse. */
+		inline virtual bool is_receive() const override { return true; };
+
+		inline virtual bool is_receiver_test() const override { return true; } ;
+
+	private:
+		/* Prevent unwanted operations. */
+		ReceiverTestMode(const ReceiverTestMode &);
+		ReceiverTestMode &operator=(const ReceiverTestMode &);
+	};
+#endif
+
+
+
 
 	/* Class that aggregates modes, created from dictionaries and
 	   locally, and provides a concept of a current mode and
