@@ -1,5 +1,5 @@
 // Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-// Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+// Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -24,29 +24,19 @@
 #include <cerrno>
 #include <sstream>
 
+#include <libcw.h>
+#include <libcw_utils.h>
+#include <cwutils/i18n.h>
+
+#ifdef ENABLE_DEV_RECEIVER_TEST
+#include <libcw_gen.h>
+#endif
 
 #include "application.h"
 #include "receiver.h"
 #include "textarea.h"
 #include "modeset.h"
 
-#include "libcw.h"
-
-#include "i18n.h"
-
-
-#ifdef XCWCP_WITH_REC_TEST
-#include <cctype>
-#include <unistd.h>
-
-#include <cw_rec_tester.h>
-
-#include "libcw2.h"
-#include "../libcw/libcw_key.h"
-#include "../libcw/libcw_gen.h"
-#include "../libcw/libcw_tq.h"
-#include "../libcw/libcw_utils.h"
-#endif
 
 
 
@@ -55,7 +45,6 @@ namespace cw {
 
 
 
-
 /**
    \brief Poll the CW library receive buffer and handle anything found
    in the buffer
@@ -477,7 +466,7 @@ void Receiver::poll_character()
 		   character. Display it. */
 		textarea->append(c);
 
-#ifdef XCWCP_WITH_REC_TEST
+#ifdef ENABLE_DEV_RECEIVER_TEST
 		fprintf(stderr, "[II] Character: '%c'\n", c);
 
 		this->rec_tester.received_string[this->rec_tester.received_string_i++] = c;
@@ -606,7 +595,7 @@ void Receiver::poll_space()
 		//fprintf(stderr, "End of word '%c'\n\n", c);
 		textarea->append(' ');
 
-#ifdef XCWCP_WITH_REC_TEST
+#ifdef ENABLE_DEV_RECEIVER_TEST
 		fprintf(stderr, "[II] Space:\n");
 
 		/* cw_receive_character() will return through 'c'
@@ -666,7 +655,7 @@ void Receiver::poll_space()
 
 
 
-#ifdef XCWCP_WITH_REC_TEST
+#ifdef ENABLE_DEV_RECEIVER_TEST
 
 
 
@@ -679,10 +668,10 @@ void low_tone_queue_callback(void * arg)
 		const char c = tester->input_string[tester->input_string_i];
 		if ('\0' == c) {
 			/* Unregister ourselves. */
-			cw_tq_register_low_level_callback_internal(tester->gen->tq, NULL, NULL, 0);
+			cw_tq_register_low_level_callback_internal(tester->helper_gen->tq, NULL, NULL, 0);
 			break;
 		} else {
-			cw_gen_enqueue_character(tester->gen, c);
+			cw_gen_enqueue_character(tester->helper_gen, c);
 			tester->input_string_i++;
 		}
 	}
@@ -721,7 +710,7 @@ void * receiver_input_generator_fn(void * arg)
 	Receiver * xcwcp_receiver = (Receiver *) arg;
 
 	cw_rec_tester_init(&xcwcp_receiver->rec_tester);
-	cw_rec_tester_init_text_buffers(&xcwcp_receiver->rec_tester, 1);
+	cw_rec_tester_init_text_buffers(&xcwcp_receiver->rec_tester, false);
 
 
 	/* Using Null sound system because this generator is only used
@@ -734,8 +723,8 @@ void * receiver_input_generator_fn(void * arg)
 	cw_gen_t * gen = cw_gen_new(&gen_conf);
 	cw_key_t key;
 
-	xcwcp_receiver->rec_tester.gen = gen;
-	cw_tq_register_low_level_callback_internal(xcwcp_receiver->rec_tester.gen->tq, low_tone_queue_callback, &xcwcp_receiver->rec_tester, 5);
+	xcwcp_receiver->rec_tester.helper_gen = gen;
+	cw_tq_register_low_level_callback_internal(xcwcp_receiver->rec_tester.helper_gen->tq, low_tone_queue_callback, &xcwcp_receiver->rec_tester, 5);
 
 	cw_key_register_generator(&key, gen);
 	cw_gen_register_value_tracking_callback_internal(gen, test_callback_func, arg);
@@ -752,7 +741,7 @@ void * receiver_input_generator_fn(void * arg)
 			/* A very short input string. */
 			break;
 		} else {
-			cw_gen_enqueue_character(xcwcp_receiver->rec_tester.gen, c);
+			cw_gen_enqueue_character(xcwcp_receiver->rec_tester.helper_gen, c);
 			xcwcp_receiver->rec_tester.input_string_i++;
 		}
 	}
@@ -764,7 +753,8 @@ void * receiver_input_generator_fn(void * arg)
 	cw_gen_delete(&gen);
 	xcwcp_receiver->rec_tester.generating_in_progress = false;
 
-	cw_rec_tester_evaluate_receive_correctness(&xcwcp_receiver->rec_tester);
+	bool test_passes = false;
+	cw_rec_tester_evaluate_receive_correctness(&xcwcp_receiver->rec_tester, &test_passes);
 
 
 	return NULL;
