@@ -1,5 +1,5 @@
 // Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-// Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+// Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -22,8 +22,11 @@
 #include <QMouseEvent>
 #include <QKeyEvent>
 
-#ifdef XCWCP_WITH_REC_TEST
-#include <cw_rec_tester.h>
+
+
+
+#ifdef ENABLE_DEV_RECEIVER_TEST
+#include <cwutils/cw_rec_tester.h>
 #endif
 
 
@@ -80,7 +83,7 @@ namespace cw {
 		/* Clear out queued data on stop, mode change, etc. */
 		void clear();
 
-#ifdef XCWCP_WITH_REC_TEST
+#ifdef ENABLE_DEV_RECEIVER_TEST
 		void start_test_code();
 		void stop_test_code();
 		pthread_t receiver_test_code_thread_id;
