@@ -1,5 +1,5 @@
 // Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-// Copyright (C) 2011-2021  Kamil Ignacak (acerion@wp.pl)
+// Copyright (C) 2011-2023  Kamil Ignacak (acerion@wp.pl)
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -24,17 +24,15 @@
 #include <deque>
 #include <sstream>
 
+#include <libcw.h>
+
+#include <cwutils/i18n.h>
 
 #include "application.h"
 #include "sender.h"
 #include "textarea.h"
 #include "modeset.h"
 
-#include "libcw.h"
-
-#include "i18n.h"
-
-
 
 
 
